'----------------------------------------------------------------------------------------
'---  FILE:       CONS.VBS
'---              Microsoft TPC-E Kit Ver. 1.2.0-1000
'---              Copyright Microsoft, 2006, 2007
'---              All Rights Reserved
'---
'---  PURPOSE:    This module executes the TPC-E Consistency tests
'---
'---  ARGUMENTS:  The calling program must pass in either "B" for beginning or
'---              "E" for ending.  Optionally, the user can pass in the server name
'---              and the password for the SQL Server sa account
'---
'----------------------------------------------------------------------------------------
'-------------------------------------
'--- open an windows scripting object
'-------------------------------------
set WshShell = CreateObject("WScript.Shell")
'-----------------------------------------------------
'--- set up windows scripting argument collection
'-----------------------------------------------------
Set objArgs = wScript.Arguments
'-------------------------------------
'--- set the test particulars
'-------------------------------------
Kit_Version = "  1.2.0-1000"
Test_Name = "Consistency"
Set objArgs = WScript.Arguments
Header_Line = "*  Executing TPC-E Consistency Tests...                                    *"
Footer_Line = "*  TPC-E Consistency Tests Complete.                                       *"
'-------------------------------------
'--- display banner message
'-------------------------------------
wScript.Echo "****************************************************************************"
wScript.Echo "*                                                                          *"
wScript.Echo "*  Microsoft TPC-E Benchmark Kit Ver." & Kit_Version & "                          *"
wScript.Echo "*                                                                          *"
wScript.Echo Header_Line
wScript.Echo "*                                                                          *"
wScript.Echo "****************************************************************************"
'----------------------------------------------------
'--- define function to check for any error messages
'----------------------------------------------------
Function CheckSQLOutput(SQL_Out)
	ErrorFlag = 0
	Set SQL_fso = CreateObject("Scripting.FileSystemObject")
	Set SQL_Out_File = SQL_fso.OpenTextFile(SQL_Out,1)
	Do While SQL_Out_File.AtEndOfStream <> True
		SQL_Line = SQL_Out_File.ReadLine
		'first check to see if SQL Server is running
		If InStr(SQL_Line, "[Shared Memory]General network error.") Then
			'display the messages and get out of here
			ErrorFlag = 1
			Wscript.Echo "SQL Server does not appear to be active on " & ServerName & "."
			Wscript.Echo "Please check the SQL Server instance and restart the Consistency test."
		End If
		'next check to see if the output contains a message about the login password
		If InStr(SQL_Line, "Login failed") Then
			'display the messages and get out of here
			ErrorFlag = 1
			Wscript.Echo "The login for userid 'sa' failed."
			Wscript.Echo "Please restart the Consistency test with the correct password."
		End If
    Loop
	SQL_Out_File.Close
	CheckSQLOutput = ErrorFlag
End Function
'-------------------------------------
'--- end function
'-------------------------------------
'-------------------------------------
'--- grab the current directory value
'-------------------------------------
ConsistencyDirectory = WshShell.CurrentDirectory & "\"
'----------------------------------------------------------------------
'--- check to see if the user passed in the server name and sa password
'----------------------------------------------------------------------
Select Case objArgs.Length
	Case 1
		'----------------------------------------
		'--- the user did not pass us anything
		'--- grab the Computer Name from Windows
		'----------------------------------------
		ServerName = WshShell.ExpandEnvironmentStrings("%COMPUTERNAME%")
		'----------------------------------------------
		'--- prompt the user to confirm the server name
		'----------------------------------------------
		ServerName = InputBox("Enter your server name",Test_Name,ServerName)
		Do While ServerName = ""
			rc = MsgBox ("You must enter a valid server name.",21)
			If rc = 2 Then
				wScript.Echo ""
				wScript.Echo "TPC-E Setup cancelled by user."
				wScript.Quit
			End If	
			ServerName = WshShell.ExpandEnvironmentStrings("%COMPUTERNAME%")
			ServerName = InputBox("Enter your server name","Database Server Name",ServerName)
		Loop
		'---------------------------------------
		'--- prompt the user for the sa password
		'---------------------------------------
		saPassword = InputBox("Enter the 'sa' password",Test_Name)
		If saPassword = "" Then
			saPassword = "Blank"
		End If
	Case 2
		'----------------------------------------------------------------
		'--- the user passed 1 argument, so assume it is the server name
		'----------------------------------------------------------------
		ServerName = objArgs(1)
		'---------------------------------------
		'--- prompt the user for the sa password
		'---------------------------------------
		saPassword = InputBox("Enter the 'sa' password",Test_Name)
		If saPassword = "" Then
			saPassword = "Blank"
		End If
	Case 3
		'---------------------------------------------------
		'--- the user passed 2 arguments, so try to use them
		'---------------------------------------------------
		ServerName = objArgs(1)
		saPassword = objArgs(2)
		If saPassword = "" Then
			saPassword = "Blank"
		End If
End Select
'-------------------------------------------------------
'--- build the SQL Server login string
'-------------------------------------------------------
If saPassword = "Blank" Then
	strSQL_Login = "-Usa "
Else
	strSQL_Login = "-Usa -P" & saPassword
End If
'------------------------------------
'--- now run the consistency tests 
'------------------------------------
wScript.Echo ""
wScript.Echo "Executing consistency tests..."
Cmd_String = "SQLCMD " & strSQL_Login & " -S" & ServerName & " -e -i" & ConsistencyDirectory & "scripts\Consistency.sql -o" & ConsistencyDirectory & "Consistency.out"
Set oExec = WshShell.Exec(Cmd_String)
Do While oExec.Status = 0
	Wscript.Sleep 100
Loop
rc = CheckSQLOutput(ConsistencyDirectory & "Consistency.out")
If rc <> 0 Then	
	Wscript.Quit
End If
wScript.Echo ""
wScript.Echo "****************************************************************************"
wScript.Echo "*                                                                          *"
wScript.Echo "*  Microsoft TPC-E Benchmark Kit Ver." & Kit_Version & "                          *"
wScript.Echo "*                                                                          *"
wScript.Echo Footer_Line
wScript.Echo "*                                                                          *"
wScript.Echo "****************************************************************************"
